@@ -21,7 +21,7 @@ use LWP::Protocol::https;
 use LWP::UserAgent;
 use Storable;
 
-our $VERSION 					= '1.17';
+our $VERSION 					= '1.18';
 use constant JSON_REMOTE_FILE 	=> 'https://raw.githubusercontent.com/serbanghita/Mobile-Detect/master/Mobile_Detect.json';
 use constant JSON_LOCAL_FILE 	=> '/var/tmp/Mobile_Detect.json';
 use constant HASH_LOCAL_FILE 	=> '/var/tmp/Mobile_Detect.db';
@@ -175,10 +175,10 @@ sub is_mobile_ua(){
 =head1 NAME
 
 	MobileDetect - The great new MobileDetect Library for Perl is finally available!
-	Perl Module for the PHP Toolchain Mobile Detect from https://github.com/serbanghita/Mobile-Detect .
-	More Information and development Tools can be found here https://www.buzzerstar.com/development/ and https://www.buzzerstar.com/ . BuzzerStar uses the Mobile Detect Perl Library to bring you the newest viral Webtrends
-	on https://www.buzzerstar.com/trending/ ; we have a daily updated Text and Picture News ticker on https://www.buzzerstar.com/newsticker/ or https://www.buzzerstar.com/kategorie/Dating News for you.
-	You can also write your own article on https://www.buzzerstar.com/schreiben.php and become a journalist.
+	Perl Module for the PHP Toolchain Mobile Detect from Serban Ghita.
+	More Information and development Tools can be found here https://www.buzzerstar.com/development/ and https://www.buzzerstar.net/ & https://www.buzzerstar.com/ . 
+	BuzzerStar uses the Mobile Detect Perl Library to bring you the newest viral Webtrendson https://www.buzzerstar.com/spiele/sudoku/ & https://www.buzzerstar.net/news/Entertainment ; we have a daily updated Text and Picture News ticker on https://www.buzzerstar.com/newsticker/ or https://www.buzzerstar.com/kategorie/Dating News for you.
+	You can also write your own article on https://www.buzzerstar.net/post.php (english) https://www.buzzerstar.com/post.php (German) and become a journalist.
 	
 	Feel free to contact me to add patches, features and software code improvements to the mobile Detection functions
 	of this Cpan Perl module. Download, add, modify, copy, distribute at your will but leave some copyright marks in it.	
@@ -187,7 +187,7 @@ sub is_mobile_ua(){
 
 =head1 VERSION
 	
-	1.17
+	1.18
 	
 =head1 DEPENDENCIE
 
@@ -222,7 +222,7 @@ Check a given string against the Mobile Detect Library that can be found here: h
 I have prepared a Perl Version, because there is no such thing in perl and i also want to show my support for Mr. Șerban Ghiță
 and his fine piece of PHP Software.
 
-The newest Version 1.17 has build in flat file database support, where the content of the downloaded json file is being preparsed
+The newest Version 1.18 has build in flat file database support, where the content of the downloaded json file is being preparsed
 and can be read into memory with the needed hash structure for perl to process. 
 
 This is the Perl Version. You need to setup LWP with HTTPS Support before (needed to regulary update the Mobile_Detect.json file
@@ -238,11 +238,14 @@ This is the Perl Version. You need to setup LWP with HTTPS Support before (neede
 	
 =head1 AUTHOR
 
-	Sebastian Enger, C<< <sebastian.enger at gmail.com> >>
+	Sebastian Enger, C<< <sebastian.enger at gmail.com> >> 2014-2015
+	Marc Qantins, C<< <qantins at googlemail.com> >> 2015
 	L<Buzz News in Deutsch|https://www.buzzerstar.com/>
-	L<Buzz Trending News auf BuzzerStar|https://www.buzzerstar.com/trending/>
+	L<Buzz News in English|https://www.buzzerstar.net/>
+	L<Witze und funny Texte auf BuzzerStar|https://www.buzzerstar.com/witze/>
 	L<BuzzerStar Newsticker mit Bild und Text|https://www.buzzerstar.com/newsticker/>
 	L<BuzzerStar Entertainment Neuigkeiten|https://www.buzzerstar.com/kategorie/Entertainment>
+	L<BuzzerStar Entertainment Buzz Viral News|https://www.buzzerstar.net/news/Entertainment>
 	
 =head1 BUGS
 
